.. _community.vmware.vmware_httpapi:


***********************
community.vmware.vmware
***********************

**HttpApi Plugin for VMware REST API**



.. contents::
   :local:
   :depth: 1


Synopsis
--------
- This HttpApi plugin provides methods to connect to VMware vCenter over a HTTP(S)-based APIs.











Status
------


Authors
~~~~~~~

- Abhijeet Kasurde (Akasurde)


.. hint::
    Configuration entries for each entry type have a low to high priority order. For example, a variable that is lower in the list will override a variable that is higher up.
